@@ -55,7 +55,7 @@ class NotificationConnector(AsyncOnStart, AsyncOnStop):
             return False
 
     async def mark_notification_as_read_internal(
-        self, user_id: int, source_type: SourceTypes, source_ids: list[int]
+        self, user_id: int, source_type: SourceTypes, source_ids: list[int], timeout: int = 5
     ) -> None:
         logger.debug(f'mark notification for user({user_id}) as read for sources({source_type}): {source_ids}')
         async with self._http_client.post(
@@ -65,6 +65,7 @@ class NotificationConnector(AsyncOnStart, AsyncOnStop):
                 'source_type': source_type,
                 'source_ids': source_ids,
             },
+            timeout=timeout,
         ) as response:
             logger.debug(f'mark notification as read done, status: {response.status}')
             response.raise_for_status()
